@echo off

:: BEGIN CONFIGURABLE ENVIRONMENT VARIABLES ::
if not defined AEM_HOME (
  set AEM_HOME=C:\aem
)
if not defined NATIVE_SERVICE_PORT (
  set NATIVE_SERVICE_PORT=8007
)
if not defined NATIVE_METRICS_PORT (
  set NATIVE_METRICS_PORT=8008
)
if not defined AZURITE_BLOB_PORT (
  set AZURITE_BLOB_PORT=10000
)
if not defined AZURITE_QUEUE_PORT (
  set AZURITE_QUEUE_PORT=10001
)
:: END CONFIGURABLE ENVIRONMENT VARIABLES ::

:: Main script begin

:: These directories must exist and be writable for the docker user
set AEM_FONTS_DIR=%AEM_HOME%\crx-quickstart\fonts
set AEM_LOGS_DIR=%AEM_HOME%\crx-quickstart\logs
set SDK_TEMP_DIR=%AEM_HOME%\crx-quickstart\temp\sdk
if exist %AEM_HOME%\crx-quickstart\fonts_user (
 set CUSTOM_FONTS_DIR=%AEM_HOME%\crx-quickstart\fonts_user
)

:: This is the mount point of SDK_TEMP_DIR in the container
set SHARED_TEMP_DIR=/mnt/shared/temp

:: forms-native-sdk image
set FORMS_NATIVE_SDK_IMAGE_FILE=${forms-native-sdk.image.name}-${forms-native-sdk.image.tag}.tar.gz
set FORMS_NATIVE_SDK_IMAGE_NAME=${forms-native-sdk.image.repo}/${forms-native-sdk.image.name}:${forms-native-sdk.image.tag}

:: forms-java-sdk image
set FORMS_JAVA_SDK_IMAGE_FILE=${forms-java-sdk.image.name}-${forms-java-sdk.image.tag}.tar.gz
set FORMS_JAVA_SDK_IMAGE_NAME=${forms-java-sdk.image.repo}/${forms-java-sdk.image.name}:${forms-java-sdk.image.tag}

set FORMS_JAVA_SDK=docker-compose.hsm.yml
set CUSTOM_FONT_SUPPORT=docker-compose.customfont.yml

goto :main

:usage
echo "Usage: sdk.bat [start ^| stop]"
exit /b 0

:checkExists
set dir=%~1
if not exist %dir% (
    echo Error: Mandatory directory %dir% does not exist, exiting ...
    exit 1
)
echo Found directory %dir%
exit /b 0

:load_image
set image_file=%1
set image_name=%2
echo Loading %image_name% ...
docker load < %image_file%
if %errorlevel% neq 0 (
    echo Error: %image_name%  could not be loaded, exiting ...
    exit 1
)
echo %image_name% loaded
setlocal EnableDelayedExpansion
goto :eof

:start_sdk_composition
set "compose_files=%~1"

if defined CUSTOM_FONTS_DIR (
    call :checkExists %CUSTOM_FONTS_DIR%
    if %errorlevel% neq 0 (
        exit /b 1
    )
    echo Found custom fonts at %CUSTOM_FONTS_DIR%
    docker-compose %compose_files% -f %CUSTOM_FONT_SUPPORT% up -d
    if %errorlevel% neq 0 (
        echo Error: SDK could not be started, exiting ...
        exit 1
    )
) else (
    docker-compose %compose_files% up -d
    if %errorlevel% neq 0 (
        echo Error: SDK could not be started, exiting ...
        exit 1
    )
)
exit /b 0

:start_sdk
:: Check for existence of critical directories, fail if missing
call :checkExists %AEM_FONTS_DIR%
if %errorlevel% neq 0 (
  exit /b 1
)
call :checkExists %AEM_LOGS_DIR%
if %errorlevel% neq 0 (
  exit /b 1
)
mkdir %SDK_TEMP_DIR%
call :checkExists %SDK_TEMP_DIR%
if %errorlevel% neq 0 (
  exit /b 1
)

:: Check whether HSM IP is specified in hsm.properties
findstr /r /v "^#" hsm.properties | findstr /c:"aws_hsm_server_ip" > nul
set hsm_server_ip_uncommented=%errorlevel%
if %hsm_server_ip_uncommented% equ 0 (
    for /f "tokens=2 delims==" %%A in ('findstr /r /v "^#" hsm.properties ^| findstr /c:"aws_hsm_server_ip"') do (
        set "VPN_TEST_HOST=%%A"
    )
    echo HSM server set to %VPN_TEST_HOST%, checking connectivity ...
    echo Pinging %VPN_TEST_HOST% to check for VPN connectivity ...
    ping -n 1 %VPN_TEST_HOST% > nul

    if %errorlevel% geq 0 (
        echo %VPN_TEST_HOST% appears to be unreachable, check whether VPN connection is active.
    ) else (
        echo %VPN_TEST_HOST% is reachable, VPN connection test successful.
    )

    call :start_sdk_composition "-f docker-compose.yml -f %FORMS_JAVA_SDK%"

) else (
     echo HSM server undefined, starting SDK without HSM support ...
     call :start_sdk_composition
)

echo SDK started successfully
exit /b 0

:stop_sdk
echo Stopping SDK ...
if defined CUSTOM_FONTS_DIR (
    call :checkExists %CUSTOM_FONTS_DIR%
    if %errorlevel% neq 0 (
    exit /b 1
    )
    docker-compose -f docker-compose.yml -f %FORMS_JAVA_SDK% -f $CUSTOM_FONT_SUPPORT down -v
    if %errorlevel% neq 0 (
        docker ps
        echo Error: Could not stop SDK, some containers may still be running ...
        exit 1
    )
) else (
    docker-compose -f docker-compose.yml -f %FORMS_JAVA_SDK% down -v
    if %errorlevel% neq 0 (
        docker ps
        echo Error: Could not stop SDK, some containers may still be running ...
        exit 1
    )
)
echo SDK stopped successfully
exit /b 0

:main
if "%1"=="start" (
    call :load_image "%FORMS_JAVA_SDK_IMAGE_FILE%" "%FORMS_JAVA_SDK_IMAGE_NAME%"
    call :load_image "%FORMS_NATIVE_SDK_IMAGE_FILE%" "%FORMS_NATIVE_SDK_IMAGE_NAME%"
    call :start_sdk
) else if "%1"=="stop" (
    call :stop_sdk
) else (
    call :usage
)
